import React, { useState, useRef, useEffect } from 'react';

var useFPSCore = function useFPSCore(_ref) {
  var _ref$fpsHistory = _ref.fpsHistory,
      fpsHistory = _ref$fpsHistory === void 0 ? 70 : _ref$fpsHistory,
      _ref$fpsSampleRate = _ref.fpsSampleRate,
      fpsSampleRate = _ref$fpsSampleRate === void 0 ? 1000 : _ref$fpsSampleRate;
  var fpsCorection = 1000 / fpsSampleRate;

  var _useState = useState(0),
      frames = _useState[0],
      _setFrames = _useState[1];

  var framesRef = useRef(frames);

  var setFrames = function setFrames(data) {
    framesRef.current = data;

    _setFrames(data);
  };

  var _useState2 = useState(+new Date()),
      prevTime = _useState2[0],
      _setPrevTime = _useState2[1];

  var prevTimeRef = useRef(prevTime);

  var setPrevTime = function setPrevTime(data) {
    prevTimeRef.current = data;

    _setPrevTime(data);
  };

  var _useState3 = useState([]),
      fps = _useState3[0],
      _setFps = _useState3[1];

  var fpsRef = useRef(fps);

  var setFps = function setFps(data) {
    fpsRef.current = data;

    _setFps(data);
  };

  useEffect(function () {
    var afRequest;

    var onRequestAnimationFrame = function onRequestAnimationFrame() {
      calcFPS();
      afRequest = window.requestAnimationFrame(onRequestAnimationFrame);
    };

    afRequest = window.requestAnimationFrame(onRequestAnimationFrame);
    return function () {
      window.cancelAnimationFrame(afRequest);
    };
  }, []);

  var calcFPS = function calcFPS() {
    var currentTime = +new Date();

    var _frames = framesRef.current + 1;

    setFrames(_frames);

    if (currentTime > prevTimeRef.current + fpsSampleRate) {
      var _fps = Math.round(_frames * fpsSampleRate / (currentTime - prevTimeRef.current) * fpsCorection);

      var sliceStart = Math.min(fpsRef.current.length - fpsHistory, 0);
      setPrevTime(+new Date());
      setFps([].concat(fpsRef.current.slice(sliceStart - 1, fpsRef.current.length), [_fps]));
      setFrames(0);
    }
  };

  return {
    frames: frames,
    fps: fps
  };
};

var useFPSDetect = function useFPSDetect(_ref) {
  var _ref$minimumFps = _ref.minimumFps,
      minimumFps = _ref$minimumFps === void 0 ? 20 : _ref$minimumFps,
      _ref$fpsSampleRate = _ref.fpsSampleRate,
      fpsSampleRate = _ref$fpsSampleRate === void 0 ? 1000 : _ref$fpsSampleRate,
      _ref$fpsHistory = _ref.fpsHistory,
      fpsHistory = _ref$fpsHistory === void 0 ? 2 : _ref$fpsHistory;

  var _useFPSCore = useFPSCore({
    fpsHistory: fpsHistory,
    fpsSampleRate: fpsSampleRate
  }),
      fps = _useFPSCore.fps;

  var _useState = useState(false),
      lowFrameRate = _useState[0],
      setLowFrameRate = _useState[1];

  useEffect(function () {
    var average = function average(array) {
      return array.reduce(function (a, b) {
        return a + b;
      }, 0) / array.length;
    };

    average(fps) <= minimumFps && setLowFrameRate(true);
  }, [fps]);
  return lowFrameRate;
};

var fpsHistory = 50;
var FPSStats = function FPSStats(_ref) {
  var _ref$top = _ref.top,
      top = _ref$top === void 0 ? 2 : _ref$top,
      _ref$left = _ref.left,
      left = _ref$left === void 0 ? 2 : _ref$left,
      _ref$bottom = _ref.bottom,
      bottom = _ref$bottom === void 0 ? 'auto' : _ref$bottom,
      _ref$right = _ref.right,
      right = _ref$right === void 0 ? 'auto' : _ref$right,
      _ref$fpsSampleRate = _ref.fpsSampleRate,
      fpsSampleRate = _ref$fpsSampleRate === void 0 ? 1000 : _ref$fpsSampleRate;

  var _useFPSCore = useFPSCore({
    fpsHistory: fpsHistory,
    fpsSampleRate: fpsSampleRate
  }),
      fps = _useFPSCore.fps;

  var wrapperStyle = {
    zIndex: 999999,
    position: 'fixed',
    height: '50px',
    width: '75px',
    padding: '3px',
    backgroundColor: 'rgba(52, 52, 52, 0.8)',
    borderRadius: '4px',
    color: '#ebebeb ',
    fontSize: '9px',
    fontFamily: 'Helvetica, Arial, sans-serif',
    textAlign: 'center',
    top: top,
    right: right,
    bottom: bottom,
    left: left
  };
  var fpsStatsStyle = {
    width: '100%',
    paddingBottom: '3px'
  };
  var width = fpsHistory * 10;
  return React.createElement("div", {
    style: wrapperStyle
  }, React.createElement("span", null, fps[fps.length - 1], " FPS"), React.createElement("svg", {
    viewBox: "0 0 " + width + " 220",
    style: fpsStatsStyle
  }, React.createElement("polyline", {
    id: "pol",
    fill: "#fff",
    stroke: "#fff",
    points: '0 220,' + fps.slice().reverse().map(function (fps, i) {
      return i * 20 + " " + (210 - fps * 3);
    }).join('\r\n') + ("," + (fps.length - 1) * 20 + " 220")
  })));
};

export { FPSStats, useFPSCore, useFPSDetect };
//# sourceMappingURL=fps-react.esm.js.map
